import random
import turtle as t 

screen = t.getscreen()
t_piece = t.Turtle()
t_dot = t.Turtle()
t_piece.color('green')
t_dot.color('red')

class Board:

	step = 50

	def __init__(self, size, num_dots):
		self.dots = []
		self.size = size
		self.initialize_dots(num_dots)
		self.piece = (0, 0)

	def initialize_dots(self, num_dots):
		count = 0
		while count < num_dots:
			x = random.randint(0, self.size - 1)
			y = random.randint(0, self.size - 1)
			if (x, y) not in self.dots and (x, y) != (0, 0):
				count += 1
				self.dots.append((x, y))

	def display(self):
		half_step = self.step / 2
		screen.register_shape('block', 
			((half_step, -half_step), (half_step, half_step), (-half_step, half_step), (-half_step, -half_step)))

		t.hideturtle()
		t.tracer(0, 0)

		def draw_square(size):
			t.pendown()
			for _ in range(4):
				t.forward(size)
				t.right(90)
			t.penup()

		t.penup()

		# draw grid 
		for i in range(self.size):
			for j in range(self.size):
				t.goto(i * self.step - 250, j * self.step - 200)
				draw_square(self.step)

		# draw dots 
		for x, y in self.dots:
			t_dot.shape('block')
			t_dot.penup()
			t_dot.goto(y * self.step - 250 + self.step / 2, x * self.step - 200 - self.step / 2)
			t_dot.stamp()

		# draw piece 
		t_piece.shape('block')
		t_piece.penup()
		t_piece.goto(self.piece[1] * self.step - 250 + self.step / 2, self.piece[0] * self.step - 200 - self.step / 2)
		t_piece.stamp()

		t.update()

	def move_piece(self, new_coords):
		self.piece = (new_coords)

	def contains_dot(self, coords):
		return coords in self.dots

	def num_dots(self):
		return len(self.dots)

	def remove_dot(self, coords):
		for i in range(len(self.dots)):
			if self.dots[i] == coords:
				self.dots.pop(i)
				return

	def piece_coords(self):
		return self.coords

class Game:

	def __init__(self, board):
		self.board = board
		self.new_coords = board.piece

	def run_game(self):

		def up():
			self.new_coords = (self.board.piece[0] + 1, self.board.piece[1])
			t_piece.clearstamps()

		def down():
			self.new_coords = (self.board.piece[0] - 1, self.board.piece[1])
			t_piece.clearstamps()

		def left():
			self.new_coords = (self.board.piece[0], self.board.piece[1] - 1)
			t_piece.clearstamps()

		def right():
			self.new_coords = (self.board.piece[0], self.board.piece[1] + 1)
			t_piece.clearstamps()

		while not self.game_over():
			screen.onkey(up, 'Up')
			screen.onkey(down, 'Down')
			screen.onkey(left, 'Left')
			screen.onkey(right, 'Right')
			screen.listen()
			if self.board.contains_dot(self.new_coords):
				self.board.remove_dot(self.new_coords)
				t_dot.clearstamps()
			self.board.move_piece(self.new_coords)
			self.board.display()

	def game_over(self):
		return self.board.num_dots() == 0


board = Board(10, 10)
board.display()

game = Game(board)
game.run_game()







